==> sped-1.35.26.tar.gz: sped-1.35.26/pythonsped/efd/layout_13.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
import layout_12
from bloco_c import bloco_c as efd_bloco_c
from bloco_1 import bloco_1 as efd_bloco_1
from bloco_g import bloco_g as efd_bloco_g

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2019'
_codigo_ = '013'  # layout_13
_versao_ = '112'


class bloco_0(layout_12.bloco_0):
    pass


class bloco_e(layout_12.bloco_e):
    pass


class bloco_1(efd_bloco_1):
    """
    BLOCO 1: OUTRAS INFORMAÇÕES
    Este bloco destina-se à prestação de outras informações exigidas pelo fisco.
    """

    class registro_1010(efd_bloco_1.registro_1010):
        """
        REGISTRO 1010: OBRIGATORIEDADE DE REGISTROS DO BLOCO 1
        Este registro deverá ser apresentado por todos os contribuintes. Caso a resposta seja “S”,
        o contribuinte está obrigado à apresentação do registro respectivo. Se houver dispensa de
        apresentação do registro pela unidade federada, a resposta para o campo específico do
        registro deverá ser “N”.
        """
        def __init__(self):
            super(bloco_1.registro_1010, self).__init__()
            self.IND_GIAF1 = ''
            self.IND_GIAF3 = ''
            self.IND_GIAF4 = ''
            self.fieldnames = ('REG', 'IND_EXP', 'IND_CCRF', 'IND_COMB', 'IND_USINA', 'IND_VA',
                               'IND_EE', 'IND_CART', 'ND_FORM', 'IND_AER', 'IND_GIAF1', 'IND_GIAF3',
                               'IND_GIAF4')
            self.formato = self.get_formato()


class bloco_c(efd_bloco_c):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_C170(efd_bloco_c.registro_C170):
        """
        REGISTRO C170: ITENS DO DOCUMENTO (CÓDIGO 01, 1B, 04 e 55).
        Registro obrigatorio para discriminar os itens da nota fiscal (mercadorias e/ou servicos
        constantes em notas conjugadas), inclusive em operacoes de entrada de mercadorias
        acompanhada de Nota Fiscal Eletronica (NF-e) de emissao de terceiros.
        """
        def __init__(self):
            super(bloco_c.registro_C170, self).__init__()
            self.VL_ABAT_NT = ''  # Valor do abatimento nao tributado e nao comercial
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'DESCR_COMPL', 'QTD', 'UNID',
                               'VL_ITEM', 'VL_DESC', 'IND_MOV', 'CST_ICMS', 'CFOP', 'COD_NAT',
                               'VL_BC_ICMS', 'ALIQ_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST', 'ALIQ_ST',
                               'VL_ICMS_ST', 'IND_APUR', 'CST_IPI', 'COD_ENQ', 'VL_BC_IPI',
                               'ALIQ_IPI', 'VL_IPI', 'CST_PIS', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_REAIS', 'VL_PIS', 'CST_COFINS',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_REAIS', 'VL_COFINS', 'COD_CTA', 'VL_ABAT_NT')
            self.formato = self.get_formato()


class bloco_g(efd_bloco_g):
    pass

==> sped-3.0.4.tar.gz: sped-3.0.4/pythonsped/efd/layout_13.py <==
# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2019 All Rights Reserved. Luiz Fernando Maciel França
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2019, Creative Commons
Autor - Tiago Henrique Prates dos Santos <tiago.santos[at]siginformatica.com.br>
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from . import layout_12
from .bloco_c import bloco_c as efd_bloco_c
from .bloco_1 import bloco_1 as efd_bloco_1
from .bloco_g import bloco_g as efd_bloco_g

# Ato COTEPE/ICMS item 3.1.1 - Tabela Versao do Leiaute
_obrigatoriedade_ = '01/01/2019'
_codigo_ = '013'  # layout_13
_versao_ = '112'


class bloco_0(layout_12.bloco_0):
    pass


class bloco_e(layout_12.bloco_e):
    pass


class bloco_1(efd_bloco_1):
    """
    BLOCO 1: OUTRAS INFORMAÇÕES
    Este bloco destina-se à prestação de outras informações exigidas pelo fisco.
    """

    class registro_1010(efd_bloco_1.registro_1010):
        """
        REGISTRO 1010: OBRIGATORIEDADE DE REGISTROS DO BLOCO 1
        Este registro deverá ser apresentado por todos os contribuintes. Caso a resposta seja “S”,
        o contribuinte está obrigado à apresentação do registro respectivo. Se houver dispensa de
        apresentação do registro pela unidade federada, a resposta para o campo específico do
        registro deverá ser “N”.
        """
        def __init__(self):
            super(bloco_1.registro_1010, self).__init__()
            self.IND_GIAF1 = ''
            self.IND_GIAF3 = ''
            self.IND_GIAF4 = ''
            self.fieldnames = ('REG', 'IND_EXP', 'IND_CCRF', 'IND_COMB', 'IND_USINA', 'IND_VA',
                               'IND_EE', 'IND_CART', 'ND_FORM', 'IND_AER', 'IND_GIAF1', 'IND_GIAF3',
                               'IND_GIAF4')
            self.formato = self.get_formato()


class bloco_c(efd_bloco_c):
    """
    BLOCO C: DOCUMENTOS FISCAIS I - MERCADORIAS (ICMS/IPI)
    """

    class registro_C170(efd_bloco_c.registro_C170):
        """
        REGISTRO C170: ITENS DO DOCUMENTO (CÓDIGO 01, 1B, 04 e 55).
        Registro obrigatorio para discriminar os itens da nota fiscal (mercadorias e/ou servicos
        constantes em notas conjugadas), inclusive em operacoes de entrada de mercadorias
        acompanhada de Nota Fiscal Eletronica (NF-e) de emissao de terceiros.
        """
        def __init__(self):
            super(bloco_c.registro_C170, self).__init__()
            self.VL_ABAT_NT = ''  # Valor do abatimento nao tributado e nao comercial
            self.fieldnames = ('REG', 'NUM_ITEM', 'COD_ITEM', 'DESCR_COMPL', 'QTD', 'UNID',
                               'VL_ITEM', 'VL_DESC', 'IND_MOV', 'CST_ICMS', 'CFOP', 'COD_NAT',
                               'VL_BC_ICMS', 'ALIQ_ICMS', 'VL_ICMS', 'VL_BC_ICMS_ST', 'ALIQ_ST',
                               'VL_ICMS_ST', 'IND_APUR', 'CST_IPI', 'COD_ENQ', 'VL_BC_IPI',
                               'ALIQ_IPI', 'VL_IPI', 'CST_PIS', 'VL_BC_PIS', 'ALIQ_PIS',
                               'QUANT_BC_PIS', 'ALIQ_PIS_REAIS', 'VL_PIS', 'CST_COFINS',
                               'VL_BC_COFINS', 'ALIQ_COFINS', 'QUANT_BC_COFINS',
                               'ALIQ_COFINS_REAIS', 'VL_COFINS', 'COD_CTA', 'VL_ABAT_NT')
            self.formato = self.get_formato()


class bloco_g(efd_bloco_g):
    pass
